@@ -17,8 +17,8 @@
 
 package org.apache.lucene.analysis.opennlp.tools;
 
-import java.io.IOException;
 import opennlp.tools.postag.POSModel;
+import opennlp.tools.postag.POSTagFormat;
 import opennlp.tools.postag.POSTagger;
 import opennlp.tools.postag.POSTaggerME;
 
@@ -29,8 +29,8 @@ import opennlp.tools.postag.POSTaggerME;
 public class NLPPOSTaggerOp {
   private final POSTagger tagger;
 
-  public NLPPOSTaggerOp(POSModel model) throws IOException {
-    tagger = new POSTaggerME(model);
+  public NLPPOSTaggerOp(POSModel model) {
+    tagger = new POSTaggerME(model, POSTagFormat.PENN);
   }
 
   public synchronized String[] getPOSTags(String[] words) {
