@@ -19,10 +19,17 @@ package org.apache.lucene.backward_codecs.lucene60;
 import org.apache.lucene.backward_codecs.lucene84.Lucene84RWCodec;
 import org.apache.lucene.codecs.Codec;
 import org.apache.lucene.tests.index.BaseFieldInfoFormatTestCase;
+import org.apache.lucene.tests.util.LuceneTestCase.Nightly;
 
+@Nightly // N-2 formats are only tested on nightly runs
 public class TestLucene60FieldInfosFormat extends BaseFieldInfoFormatTestCase {
   @Override
   protected Codec getCodec() {
     return new Lucene84RWCodec();
   }
+
+  @Override
+  protected boolean supportDocValuesSkipIndex() {
+    return false;
+  }
 }
