@@ -25,21 +25,20 @@ import java.nio.ByteOrder;
 import java.util.Arrays;
 import java.util.Objects;
 import java.util.Optional;
+import java.util.function.Function;
 import org.apache.lucene.util.ArrayUtil;
 import org.apache.lucene.util.BitUtil;
 import org.apache.lucene.util.Constants;
-import org.apache.lucene.util.GroupVIntUtil;
 import org.apache.lucene.util.IOConsumer;
 
 /**
  * Base IndexInput implementation that uses an array of MemorySegments to represent a file.
  *
- * <p>For efficiency, this class requires that the segment size are a power-of-two (<code>
+ * <p>For efficiency, this class requires that the segment size is a power of two (<code>
  * chunkSizePower</code>).
  */
 @SuppressWarnings("preview")
-abstract class MemorySegmentIndexInput extends IndexInput
-    implements RandomAccessInput, MemorySegmentAccessInput {
+abstract class MemorySegmentIndexInput extends IndexInput implements MemorySegmentAccessInput {
   static final ValueLayout.OfByte LAYOUT_BYTE = ValueLayout.JAVA_BYTE;
   static final ValueLayout.OfShort LAYOUT_LE_SHORT =
       ValueLayout.JAVA_SHORT_UNALIGNED.withOrder(ByteOrder.LITTLE_ENDIAN);
@@ -57,6 +56,7 @@ abstract class MemorySegmentIndexInput extends IndexInput
   final boolean confined;
   final Arena arena;
   final MemorySegment[] segments;
+  final Function<IOContext, ReadAdvice> toReadAdvice;
 
   int curSegmentIndex = -1;
   MemorySegment
@@ -70,14 +70,15 @@ abstract class MemorySegmentIndexInput extends IndexInput
       MemorySegment[] segments,
       long length,
       int chunkSizePower,
-      boolean confined) {
+      boolean confined,
+      Function<IOContext, ReadAdvice> toReadAdvice) {
     assert Arrays.stream(segments).map(MemorySegment::scope).allMatch(arena.scope()::equals);
     if (segments.length == 1) {
       return new SingleSegmentImpl(
-          resourceDescription, arena, segments[0], length, chunkSizePower, confined);
+          resourceDescription, arena, segments[0], length, chunkSizePower, confined, toReadAdvice);
     } else {
       return new MultiSegmentImpl(
-          resourceDescription, arena, segments, 0, length, chunkSizePower, confined);
+          resourceDescription, arena, segments, 0, length, chunkSizePower, confined, toReadAdvice);
     }
   }
 
@@ -87,7 +88,8 @@ abstract class MemorySegmentIndexInput extends IndexInput
       MemorySegment[] segments,
       long length,
       int chunkSizePower,
-      boolean confined) {
+      boolean confined,
+      Function<IOContext, ReadAdvice> toReadAdvice) {
     super(resourceDescription);
     this.arena = arena;
     this.segments = segments;
@@ -96,6 +98,7 @@ abstract class MemorySegmentIndexInput extends IndexInput
     this.confined = confined;
     this.chunkSizeMask = (1L << chunkSizePower) - 1L;
     this.curSegment = segments[0];
+    this.toReadAdvice = toReadAdvice;
   }
 
   void ensureOpen() {
@@ -359,7 +362,11 @@ abstract class MemorySegmentIndexInput extends IndexInput
   }
 
   @Override
-  public void updateReadAdvice(ReadAdvice readAdvice) throws IOException {
+  public void updateIOContext(IOContext context) throws IOException {
+    updateReadAdvice(toReadAdvice.apply(context));
+  }
+
+  private void updateReadAdvice(ReadAdvice readAdvice) throws IOException {
     if (NATIVE_ACCESS.isEmpty()) {
       return;
     }
@@ -447,23 +454,6 @@ abstract class MemorySegmentIndexInput extends IndexInput
     }
   }
 
-  @Override
-  public void readGroupVInt(int[] dst, int offset) throws IOException {
-    try {
-      final int len =
-          GroupVIntUtil.readGroupVInt(
-              this,
-              curSegment.byteSize() - curPosition,
-              p -> curSegment.get(LAYOUT_LE_INT, p),
-              curPosition,
-              dst,
-              offset);
-      curPosition += len;
-    } catch (NullPointerException | IllegalStateException e) {
-      throw alreadyClosed(e);
-    }
-  }
-
   @Override
   public void readBytes(long pos, byte[] b, int offset, int len) throws IOException {
     try {
@@ -570,7 +560,8 @@ abstract class MemorySegmentIndexInput extends IndexInput
               segments[0],
               length,
               chunkSizePower,
-              confined);
+              confined,
+              toReadAdvice);
     } else {
       clone =
           new MultiSegmentImpl(
@@ -580,7 +571,8 @@ abstract class MemorySegmentIndexInput extends IndexInput
               ((MultiSegmentImpl) this).offset,
               length,
               chunkSizePower,
-              confined);
+              confined,
+              toReadAdvice);
     }
     try {
       clone.seek(getFilePointer());
@@ -616,8 +608,9 @@ abstract class MemorySegmentIndexInput extends IndexInput
 
   @Override
   public final MemorySegmentIndexInput slice(
-      String sliceDescription, long offset, long length, ReadAdvice advice) throws IOException {
+      String sliceDescription, long offset, long length, IOContext context) throws IOException {
     MemorySegmentIndexInput slice = slice(sliceDescription, offset, length);
+    ReadAdvice advice = toReadAdvice.apply(context);
     if (NATIVE_ACCESS.isPresent() && advice != ReadAdvice.NORMAL) {
       // No need to madvise with a normal advice, since it's the OS' default.
       final NativeAccess nativeAccess = NATIVE_ACCESS.get();
@@ -669,7 +662,8 @@ abstract class MemorySegmentIndexInput extends IndexInput
           isClone ? slices[0] : slices[0].asSlice(offset, length),
           length,
           chunkSizePower,
-          confined);
+          confined,
+          toReadAdvice);
     } else {
       return new MultiSegmentImpl(
           newResourceDescription,
@@ -678,7 +672,8 @@ abstract class MemorySegmentIndexInput extends IndexInput
           offset,
           length,
           chunkSizePower,
-          confined);
+          confined,
+          toReadAdvice);
     }
   }
 
@@ -723,14 +718,16 @@ abstract class MemorySegmentIndexInput extends IndexInput
         MemorySegment segment,
         long length,
         int chunkSizePower,
-        boolean confined) {
+        boolean confined,
+        Function<IOContext, ReadAdvice> toReadAdvice) {
       super(
           resourceDescription,
           arena,
           new MemorySegment[] {segment},
           length,
           chunkSizePower,
-          confined);
+          confined,
+          toReadAdvice);
       this.curSegmentIndex = 0;
     }
 
@@ -833,8 +830,9 @@ abstract class MemorySegmentIndexInput extends IndexInput
         long offset,
         long length,
         int chunkSizePower,
-        boolean confined) {
-      super(resourceDescription, arena, segments, length, chunkSizePower, confined);
+        boolean confined,
+        Function<IOContext, ReadAdvice> toReadAdvice) {
+      super(resourceDescription, arena, segments, length, chunkSizePower, confined, toReadAdvice);
       this.offset = offset;
       try {
         seek(0L);
