@@ -109,7 +109,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.STRING));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(2, td.totalHits.value);
+    assertEquals(2, td.totalHits.value());
     // 'bar' comes before 'foo'
     assertEquals("bar", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals("foo", searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -137,7 +137,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.STRING, true));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(2, td.totalHits.value);
+    assertEquals(2, td.totalHits.value());
     // 'foo' comes after 'bar' in reverse order
     assertEquals("foo", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals("bar", searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -165,7 +165,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.STRING_VAL));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(2, td.totalHits.value);
+    assertEquals(2, td.totalHits.value());
     // 'bar' comes before 'foo'
     assertEquals("bar", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals("foo", searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -193,7 +193,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.STRING_VAL, true));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(2, td.totalHits.value);
+    assertEquals(2, td.totalHits.value());
     // 'foo' comes after 'bar' in reverse order
     assertEquals("foo", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals("bar", searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -225,7 +225,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.INT));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(3, td.totalHits.value);
+    assertEquals(3, td.totalHits.value());
     // numeric order
     assertEquals("-1", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals("4", searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -258,7 +258,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.INT, true));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(3, td.totalHits.value);
+    assertEquals(3, td.totalHits.value());
     // reverse numeric order
     assertEquals("300000", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals("4", searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -289,7 +289,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.INT));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(3, td.totalHits.value);
+    assertEquals(3, td.totalHits.value());
     // null is treated as a 0
     assertEquals("-1", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertNull(searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -324,7 +324,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(sortField);
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(3, td.totalHits.value);
+    assertEquals(3, td.totalHits.value());
     // null is treated as a Integer.MAX_VALUE
     assertEquals("-1", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals("4", searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -357,7 +357,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.LONG));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(3, td.totalHits.value);
+    assertEquals(3, td.totalHits.value());
     // numeric order
     assertEquals("-1", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals("4", searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -390,7 +390,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.LONG, true));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(3, td.totalHits.value);
+    assertEquals(3, td.totalHits.value());
     // reverse numeric order
     assertEquals("3000000000", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals("4", searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -421,7 +421,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.LONG));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(3, td.totalHits.value);
+    assertEquals(3, td.totalHits.value());
     // null is treated as 0
     assertEquals("-1", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertNull(searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -456,7 +456,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(sortField);
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(3, td.totalHits.value);
+    assertEquals(3, td.totalHits.value());
     // null is treated as Long.MAX_VALUE
     assertEquals("-1", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals("4", searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -489,7 +489,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.FLOAT));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(3, td.totalHits.value);
+    assertEquals(3, td.totalHits.value());
     // numeric order
     assertEquals("-1.3", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals("4.2", searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -522,7 +522,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.FLOAT, true));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(3, td.totalHits.value);
+    assertEquals(3, td.totalHits.value());
     // reverse numeric order
     assertEquals("30.1", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals("4.2", searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -553,7 +553,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.FLOAT));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(3, td.totalHits.value);
+    assertEquals(3, td.totalHits.value());
     // null is treated as 0
     assertEquals("-1.3", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertNull(searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -588,7 +588,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(sortField);
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(3, td.totalHits.value);
+    assertEquals(3, td.totalHits.value());
     // null is treated as Float.MAX_VALUE
     assertEquals("-1.3", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals("4.2", searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -625,7 +625,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.DOUBLE));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(4, td.totalHits.value);
+    assertEquals(4, td.totalHits.value());
     // numeric order
     assertEquals("-1.3", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals(
@@ -658,7 +658,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.DOUBLE));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(2, td.totalHits.value);
+    assertEquals(2, td.totalHits.value());
     // numeric order
     assertEquals("-0", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals("+0", searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -694,7 +694,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.DOUBLE, true));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(4, td.totalHits.value);
+    assertEquals(4, td.totalHits.value());
     // numeric order
     assertEquals("30.1", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals(
@@ -732,7 +732,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.DOUBLE));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(4, td.totalHits.value);
+    assertEquals(4, td.totalHits.value());
     // null treated as a 0
     assertEquals("-1.3", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertNull(searcher.storedFields().document(td.scoreDocs[1].doc).get("value"));
@@ -775,7 +775,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(sortField);
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(4, td.totalHits.value);
+    assertEquals(4, td.totalHits.value());
     // null treated as Double.MAX_VALUE
     assertEquals("-1.3", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
     assertEquals(
@@ -826,7 +826,7 @@ public class TestSort extends LuceneTestCase {
             new SortField("value2", SortField.Type.LONG));
 
     TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(4, td.totalHits.value);
+    assertEquals(4, td.totalHits.value());
     // 'bar' comes before 'foo'
     assertEquals("bar", searcher.storedFields().document(td.scoreDocs[0].doc).get("value1"));
     assertEquals("bar", searcher.storedFields().document(td.scoreDocs[1].doc).get("value1"));
@@ -840,7 +840,7 @@ public class TestSort extends LuceneTestCase {
 
     // Now with overflow
     td = searcher.search(new MatchAllDocsQuery(), 1, sort);
-    assertEquals(4, td.totalHits.value);
+    assertEquals(4, td.totalHits.value());
     assertEquals("bar", searcher.storedFields().document(td.scoreDocs[0].doc).get("value1"));
     assertEquals("0", searcher.storedFields().document(td.scoreDocs[0].doc).get("value2"));
 
@@ -896,7 +896,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.STRING));
 
     TopFieldDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(2, td.totalHits.value);
+    assertEquals(2, td.totalHits.value());
     assertNull(((FieldDoc) td.scoreDocs[0]).fields[0]);
     assertNull(((FieldDoc) td.scoreDocs[1]).fields[0]);
 
@@ -932,7 +932,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.INT));
 
     TopFieldDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(2, td.totalHits.value);
+    assertEquals(2, td.totalHits.value());
     assertEquals(0, ((FieldDoc) td.scoreDocs[0]).fields[0]);
     assertEquals(0, ((FieldDoc) td.scoreDocs[1]).fields[0]);
 
@@ -968,7 +968,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.LONG));
 
     TopFieldDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(2, td.totalHits.value);
+    assertEquals(2, td.totalHits.value());
     assertEquals(0L, ((FieldDoc) td.scoreDocs[0]).fields[0]);
     assertEquals(0L, ((FieldDoc) td.scoreDocs[1]).fields[0]);
 
@@ -1004,7 +1004,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.DOUBLE));
 
     TopFieldDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(2, td.totalHits.value);
+    assertEquals(2, td.totalHits.value());
     assertEquals(0.0, ((FieldDoc) td.scoreDocs[0]).fields[0]);
     assertEquals(0.0, ((FieldDoc) td.scoreDocs[1]).fields[0]);
 
@@ -1040,7 +1040,7 @@ public class TestSort extends LuceneTestCase {
     Sort sort = new Sort(new SortField("value", SortField.Type.FLOAT));
 
     TopFieldDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
-    assertEquals(2, td.totalHits.value);
+    assertEquals(2, td.totalHits.value());
     assertEquals(0.0f, ((FieldDoc) td.scoreDocs[0]).fields[0]);
     assertEquals(0.0f, ((FieldDoc) td.scoreDocs[1]).fields[0]);
 
