@@ -138,15 +138,6 @@ public class ToParentBlockJoinQuery extends Query {
       this.scoreMode = scoreMode;
     }
 
-    @Override
-    public Scorer scorer(LeafReaderContext context) throws IOException {
-      final ScorerSupplier scorerSupplier = scorerSupplier(context);
-      if (scorerSupplier == null) {
-        return null;
-      }
-      return scorerSupplier.get(Long.MAX_VALUE);
-    }
-
     // NOTE: acceptDocs applies (and is checked) only in the
     // parent document space
     @Override
@@ -168,8 +159,19 @@ public class ToParentBlockJoinQuery extends Query {
 
         @Override
         public Scorer get(long leadCost) throws IOException {
-          return new BlockJoinScorer(
-              BlockJoinWeight.this, childScorerSupplier.get(leadCost), parents, scoreMode);
+          return new BlockJoinScorer(childScorerSupplier.get(leadCost), parents, scoreMode);
+        }
+
+        @Override
+        public BulkScorer bulkScorer() throws IOException {
+          if (scoreMode == ScoreMode.None) {
+            // BlockJoinBulkScorer evaluates all child hits exhaustively, but when scoreMode is None
+            // we only need to evaluate a single child doc per parent. In this case, use the default
+            // bulk scorer instead, which uses BlockJoinScorer to iterate over child hits.
+            // BlockJoinScorer is optimized to skip child hit evaluation when scoreMode is None.
+            return super.bulkScorer();
+          }
+          return new BlockJoinBulkScorer(childScorerSupplier.bulkScorer(), parents, scoreMode);
         }
 
         @Override
@@ -186,22 +188,6 @@ public class ToParentBlockJoinQuery extends Query {
       };
     }
 
-    @Override
-    public BulkScorer bulkScorer(LeafReaderContext context) throws IOException {
-      if (scoreMode == ScoreMode.None) {
-        // BlockJoinBulkScorer evaluates all child hits exhaustively, but when scoreMode is None
-        // we only need to evaluate a single child doc per parent. In this case, use the default
-        // bulk scorer instead, which uses BlockJoinScorer to iterate over child hits.
-        // BlockJoinScorer is optimized to skip child hit evaluation when scoreMode is None.
-        return super.bulkScorer(context);
-      }
-
-      BulkScorer childBulkScorer = in.bulkScorer(context);
-      return childBulkScorer != null
-          ? new BlockJoinBulkScorer(childBulkScorer, parentsFilter.getBitSet(context), scoreMode)
-          : null;
-    }
-
     @Override
     public Explanation explain(LeafReaderContext context, int doc) throws IOException {
       BlockJoinScorer scorer = (BlockJoinScorer) scorer(context);
@@ -311,19 +297,16 @@ public class ToParentBlockJoinQuery extends Query {
     private final ScoreMode scoreMode;
     private double score;
     private int freq;
-    private int currentParent;
 
     public Score(ScoreMode scoreMode) {
       this.scoreMode = scoreMode;
       this.score = 0;
       this.freq = 0;
-      this.currentParent = -1;
     }
 
-    public void reset(Scorable firstChildScorer, int currentParent) throws IOException {
+    public void reset(Scorable firstChildScorer) throws IOException {
       score = scoreMode == ScoreMode.None ? 0 : firstChildScorer.score();
       freq = 1;
-      this.currentParent = currentParent;
     }
 
     public void addChildScore(Scorable childScorer) throws IOException {
@@ -356,11 +339,6 @@ public class ToParentBlockJoinQuery extends Query {
       }
       return (float) score;
     }
-
-    @Override
-    public int docID() {
-      return currentParent;
-    }
   }
 
   static class BlockJoinScorer extends Scorer {
@@ -373,9 +351,7 @@ public class ToParentBlockJoinQuery extends Query {
     private final ParentTwoPhase parentTwoPhase;
     private final Score parentScore;
 
-    public BlockJoinScorer(
-        Weight weight, Scorer childScorer, BitSet parentBits, ScoreMode scoreMode) {
-      super(weight);
+    public BlockJoinScorer(Scorer childScorer, BitSet parentBits, ScoreMode scoreMode) {
       // System.out.println("Q.init firstChildDoc=" + firstChildDoc);
       this.parentBits = parentBits;
       this.childScorer = childScorer;
@@ -445,7 +421,7 @@ public class ToParentBlockJoinQuery extends Query {
 
       float score = 0;
       if (scoreMode != ScoreMode.None) {
-        parentScore.reset(childScorer, parentApproximation.docID());
+        parentScore.reset(childScorer);
         while (childApproximation.nextDoc() < parentApproximation.docID()) {
           if (childTwoPhase == null || childTwoPhase.matches()) {
             parentScore.addChildScore(childScorer);
@@ -592,11 +568,6 @@ public class ToParentBlockJoinQuery extends Query {
                   return currentParentScore.score();
                 }
 
-                @Override
-                public int docID() {
-                  return currentParent;
-                }
-
                 @Override
                 public void setMinCompetitiveScore(float minScore) throws IOException {
                   if (scoreMode == ScoreMode.None || scoreMode == ScoreMode.Max) {
@@ -615,7 +586,7 @@ public class ToParentBlockJoinQuery extends Query {
             }
 
             currentParent = parents.nextSetBit(doc);
-            currentParentScore.reset(scorer, currentParent);
+            currentParentScore.reset(scorer);
           } else if (doc == currentParent) {
             throw new IllegalStateException(
                 "Child query must not match same docs with parent filter. "
