@@ -17,7 +17,6 @@
 
 package org.apache.lucene.sandbox.facet;
 
-import com.carrotsearch.randomizedtesting.generators.RandomNumbers;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -39,6 +38,7 @@ import org.apache.lucene.sandbox.facet.iterators.ComparableSupplier;
 import org.apache.lucene.sandbox.facet.iterators.OrdinalIterator;
 import org.apache.lucene.sandbox.facet.iterators.TopnOrdinalIterator;
 import org.apache.lucene.sandbox.facet.recorders.CountFacetRecorder;
+import org.apache.lucene.sandbox.facet.utils.ComparableUtils;
 import org.apache.lucene.search.IndexSearcher;
 import org.apache.lucene.search.MatchAllDocsQuery;
 import org.apache.lucene.store.Directory;
@@ -288,7 +288,7 @@ public class TestLongValueFacet extends SandboxFacetTestCase {
       if (random().nextBoolean()) {
         topN = docCount;
       } else {
-        topN = RandomNumbers.randomIntBetween(random(), 1, docCount - 1);
+        topN = random().nextInt(1, docCount);
       }
       if (VERBOSE) {
         System.out.println("  topN=" + topN);
@@ -305,8 +305,8 @@ public class TestLongValueFacet extends SandboxFacetTestCase {
           topN);
 
       // subset of docs
-      int minId = RandomNumbers.randomIntBetween(random(), 0, docCount - 1);
-      int maxId = RandomNumbers.randomIntBetween(random(), 0, docCount - 1);
+      int minId = random().nextInt(docCount);
+      int maxId = random().nextInt(docCount);
       if (minId > maxId) {
         int tmp = minId;
         minId = maxId;
@@ -386,7 +386,7 @@ public class TestLongValueFacet extends SandboxFacetTestCase {
       if (random().nextBoolean()) {
         topN = docCount;
       } else {
-        topN = RandomNumbers.randomIntBetween(random(), 1, docCount - 1);
+        topN = random().nextInt(1, docCount);
       }
       actual = getTopChildren(topN, "field", longValuesFacetCutter, countRecorder);
       assertSame(
@@ -418,7 +418,7 @@ public class TestLongValueFacet extends SandboxFacetTestCase {
     if (random().nextBoolean()) {
       maxValue = random().nextLong() & Long.MAX_VALUE;
     } else {
-      maxValue = RandomNumbers.randomLongBetween(random(), 0, 999);
+      maxValue = random().nextInt(1000);
     }
     if (VERBOSE) {
       System.out.println(
@@ -551,7 +551,7 @@ public class TestLongValueFacet extends SandboxFacetTestCase {
       if (random().nextBoolean()) {
         topN = docCount;
       } else {
-        topN = RandomNumbers.randomIntBetween(random(), 1, docCount - 1);
+        topN = random().nextInt(1, docCount);
       }
       if (VERBOSE) {
         System.out.println("  topN=" + topN);
@@ -568,8 +568,8 @@ public class TestLongValueFacet extends SandboxFacetTestCase {
           topN);
 
       // subset of docs
-      int minId = RandomNumbers.randomIntBetween(random(), 0, docCount - 1);
-      int maxId = RandomNumbers.randomIntBetween(random(), 0, docCount - 1);
+      int minId = random().nextInt(docCount);
+      int maxId = random().nextInt(docCount);
       if (minId > maxId) {
         int tmp = minId;
         minId = maxId;
@@ -627,7 +627,7 @@ public class TestLongValueFacet extends SandboxFacetTestCase {
       if (random().nextBoolean()) {
         topN = docCount;
       } else {
-        topN = RandomNumbers.randomIntBetween(random(), 1, docCount - 1);
+        topN = random().nextInt(1, docCount);
       }
       actual = getTopChildren(topN, "field", longValuesFacetCutter, countRecorder);
       assertSame(
