@@ -18,6 +18,7 @@
 package org.apache.lucene.tests.codecs.asserting;
 
 import java.io.IOException;
+import java.util.Map;
 import java.util.concurrent.atomic.AtomicInteger;
 import org.apache.lucene.codecs.KnnFieldVectorsWriter;
 import org.apache.lucene.codecs.KnnVectorsFormat;
@@ -33,9 +34,10 @@ import org.apache.lucene.index.SegmentReadState;
 import org.apache.lucene.index.SegmentWriteState;
 import org.apache.lucene.index.Sorter;
 import org.apache.lucene.index.VectorEncoding;
+import org.apache.lucene.search.AcceptDocs;
 import org.apache.lucene.search.KnnCollector;
+import org.apache.lucene.tests.search.AssertingAcceptDocs;
 import org.apache.lucene.tests.util.TestUtil;
-import org.apache.lucene.util.Bits;
 import org.apache.lucene.util.hnsw.HnswGraph;
 
 /** Wraps the default KnnVectorsFormat and provides additional assertions. */
@@ -103,22 +105,18 @@ public class AssertingKnnVectorsFormat extends KnnVectorsFormat {
     }
   }
 
-  static class AssertingKnnVectorsReader extends KnnVectorsReader implements HnswGraphProvider {
-    final KnnVectorsReader delegate;
-    final FieldInfos fis;
-    final boolean mergeInstance;
-    AtomicInteger mergeInstanceCount = new AtomicInteger();
-    AtomicInteger finishMergeCount = new AtomicInteger();
+  /** Wraps a AssertingKnnVectorsReader providing additional assertions. */
+  public static class AssertingKnnVectorsReader extends KnnVectorsReader
+      implements HnswGraphProvider {
+    public final KnnVectorsReader delegate;
+    private final FieldInfos fis;
+    private final AtomicInteger mergeInstanceCount = new AtomicInteger();
+    private final AtomicInteger finishMergeCount = new AtomicInteger();
 
-    AssertingKnnVectorsReader(KnnVectorsReader delegate, FieldInfos fis) {
-      this(delegate, fis, false);
-    }
-
-    AssertingKnnVectorsReader(KnnVectorsReader delegate, FieldInfos fis, boolean mergeInstance) {
+    private AssertingKnnVectorsReader(KnnVectorsReader delegate, FieldInfos fis) {
       assert delegate != null;
       this.delegate = delegate;
       this.fis = fis;
-      this.mergeInstance = mergeInstance;
     }
 
     @Override
@@ -155,37 +153,51 @@ public class AssertingKnnVectorsFormat extends KnnVectorsFormat {
     }
 
     @Override
-    public void search(String field, float[] target, KnnCollector knnCollector, Bits acceptDocs)
+    public void search(
+        String field, float[] target, KnnCollector knnCollector, AcceptDocs acceptDocs)
         throws IOException {
-      assert !mergeInstance;
       FieldInfo fi = fis.fieldInfo(field);
       assert fi != null
           && fi.getVectorDimension() > 0
           && fi.getVectorEncoding() == VectorEncoding.FLOAT32;
+      acceptDocs = AssertingAcceptDocs.wrap(acceptDocs);
       delegate.search(field, target, knnCollector, acceptDocs);
     }
 
     @Override
-    public void search(String field, byte[] target, KnnCollector knnCollector, Bits acceptDocs)
+    public void search(
+        String field, byte[] target, KnnCollector knnCollector, AcceptDocs acceptDocs)
         throws IOException {
-      assert !mergeInstance;
       FieldInfo fi = fis.fieldInfo(field);
       assert fi != null
           && fi.getVectorDimension() > 0
           && fi.getVectorEncoding() == VectorEncoding.BYTE;
+      acceptDocs = AssertingAcceptDocs.wrap(acceptDocs);
       delegate.search(field, target, knnCollector, acceptDocs);
     }
 
     @Override
-    public KnnVectorsReader getMergeInstance() {
-      assert !mergeInstance;
+    public KnnVectorsReader getMergeInstance() throws IOException {
       var mergeVectorsReader = delegate.getMergeInstance();
       assert mergeVectorsReader != null;
       mergeInstanceCount.incrementAndGet();
+      AtomicInteger parentMergeFinishCount = this.finishMergeCount;
+
+      return new AssertingKnnVectorsReader(mergeVectorsReader, AssertingKnnVectorsReader.this.fis) {
+        private boolean finished;
+
+        @Override
+        public void search(
+            String field, float[] target, KnnCollector knnCollector, AcceptDocs acceptDocs) {
+          assert false : "This instance should only be used for merging";
+        }
+
+        @Override
+        public void search(
+            String field, byte[] target, KnnCollector knnCollector, AcceptDocs acceptDocs) {
+          assert false : "This instance should only be used for merging";
+        }
 
-      final var parent = this;
-      return new AssertingKnnVectorsReader(
-          mergeVectorsReader, AssertingKnnVectorsReader.this.fis, true) {
         @Override
         public KnnVectorsReader getMergeInstance() {
           assert false; // merging from a merge instance it not allowed
@@ -194,9 +206,10 @@ public class AssertingKnnVectorsFormat extends KnnVectorsFormat {
 
         @Override
         public void finishMerge() throws IOException {
-          assert mergeInstance;
+          assert !finished : "Merging already finished";
+          finished = true;
           delegate.finishMerge();
-          parent.finishMergeCount.incrementAndGet();
+          parentMergeFinishCount.incrementAndGet();
         }
 
         @Override
@@ -208,16 +221,18 @@ public class AssertingKnnVectorsFormat extends KnnVectorsFormat {
 
     @Override
     public void finishMerge() throws IOException {
-      assert mergeInstance;
-      delegate.finishMerge();
-      finishMergeCount.incrementAndGet();
+      assert false; // can only finish merge on the merge instance
+    }
+
+    @Override
+    public Map<String, Long> getOffHeapByteSize(FieldInfo fieldInfo) {
+      return delegate.getOffHeapByteSize(fieldInfo);
     }
 
     @Override
     public void close() throws IOException {
-      assert !mergeInstance;
-      delegate.close();
       delegate.close();
+      delegate.close(); // impls should be able to handle multiple closes
       assert finishMergeCount.get() <= 0 || mergeInstanceCount.get() == finishMergeCount.get();
     }
 
