@@ -25,6 +25,7 @@ import java.io.IOException;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
+import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicReference;
@@ -34,7 +35,10 @@ import org.apache.lucene.codecs.KnnFieldVectorsWriter;
 import org.apache.lucene.codecs.KnnVectorsFormat;
 import org.apache.lucene.codecs.KnnVectorsReader;
 import org.apache.lucene.codecs.KnnVectorsWriter;
+import org.apache.lucene.codecs.hnsw.HnswGraphProvider;
+import org.apache.lucene.codecs.lucene99.Lucene99HnswVectorsReader;
 import org.apache.lucene.codecs.perfield.PerFieldKnnVectorsFormat;
+import org.apache.lucene.codecs.simpletext.SimpleTextKnnVectorsReader;
 import org.apache.lucene.document.Document;
 import org.apache.lucene.document.Field;
 import org.apache.lucene.document.KnnByteVectorField;
@@ -69,6 +73,7 @@ import org.apache.lucene.index.StoredFields;
 import org.apache.lucene.index.Term;
 import org.apache.lucene.index.VectorEncoding;
 import org.apache.lucene.index.VectorSimilarityFunction;
+import org.apache.lucene.search.AcceptDocs;
 import org.apache.lucene.search.DocIdSetIterator;
 import org.apache.lucene.search.Sort;
 import org.apache.lucene.search.SortField;
@@ -77,6 +82,7 @@ import org.apache.lucene.search.TotalHits;
 import org.apache.lucene.search.VectorScorer;
 import org.apache.lucene.store.Directory;
 import org.apache.lucene.store.FSDirectory;
+import org.apache.lucene.tests.codecs.asserting.AssertingKnnVectorsFormat;
 import org.apache.lucene.tests.util.TestUtil;
 import org.apache.lucene.util.Bits;
 import org.apache.lucene.util.BytesRef;
@@ -85,6 +91,7 @@ import org.apache.lucene.util.InfoStream;
 import org.apache.lucene.util.StringHelper;
 import org.apache.lucene.util.VectorUtil;
 import org.apache.lucene.util.Version;
+import org.apache.lucene.util.quantization.QuantizedVectorsReader;
 import org.junit.Before;
 
 /**
@@ -450,6 +457,7 @@ public abstract class BaseKnnVectorsFormatTestCase extends BaseIndexFileFormatTe
           assertEquals(0, iterator.nextDoc());
           assertEquals(0, vectorValues.vectorValue(0)[0], 0);
           assertEquals(NO_MORE_DOCS, iterator.nextDoc());
+          assertOffHeapByteSize(r, fieldName);
         }
       }
     }
@@ -814,7 +822,11 @@ public abstract class BaseKnnVectorsFormatTestCase extends BaseIndexFileFormatTe
         // assert that knn search doesn't fail on a field with all deleted docs
         TopDocs results =
             leafReader.searchNearestVectors(
-                "v", randomNormalizedVector(4), 1, leafReader.getLiveDocs(), Integer.MAX_VALUE);
+                "v",
+                randomNormalizedVector(4),
+                1,
+                AcceptDocs.fromLiveDocs(leafReader.getLiveDocs(), leafReader.maxDoc()),
+                Integer.MAX_VALUE);
         assertEquals(0, results.scoreDocs.length);
       }
     }
@@ -1066,6 +1078,7 @@ public abstract class BaseKnnVectorsFormatTestCase extends BaseIndexFileFormatTe
         assertNotNull(values);
         assertEquals(0, values.size());
         assertNull(values.scorer(new float[] {2, 3, 5, 6}));
+        assertOffHeapByteSize(r, "v");
       }
     }
   }
@@ -1092,6 +1105,7 @@ public abstract class BaseKnnVectorsFormatTestCase extends BaseIndexFileFormatTe
         assertNotNull(values);
         assertEquals(0, values.size());
         assertNull(values.scorer(new byte[] {2, 3, 5, 6}));
+        assertOffHeapByteSize(r, "v");
       }
     }
   }
@@ -1471,9 +1485,17 @@ public abstract class BaseKnnVectorsFormatTestCase extends BaseIndexFileFormatTe
           TopDocs results =
               ctx.reader()
                   .searchNearestVectors(
-                      fieldName, randomNormalizedVector(dimension), k, liveDocs, visitedLimit);
+                      fieldName,
+                      randomNormalizedVector(dimension),
+                      k,
+                      AcceptDocs.fromLiveDocs(liveDocs, ctx.reader().maxDoc()),
+                      visitedLimit);
           assertEquals(TotalHits.Relation.GREATER_THAN_OR_EQUAL_TO, results.totalHits.relation());
-          assertEquals(visitedLimit, results.totalHits.value());
+          int size = Lucene99HnswVectorsReader.EXHAUSTIVE_BULK_SCORE_ORDS;
+          assertTrue(
+              visitedLimit == results.totalHits.value()
+                  || ((visitedLimit + size - 1) / size) * ((long) size)
+                      == results.totalHits.value());
 
           // check the limit is not hit when it clearly exceeds the number of vectors
           k = vectorValues.size();
@@ -1481,9 +1503,14 @@ public abstract class BaseKnnVectorsFormatTestCase extends BaseIndexFileFormatTe
           results =
               ctx.reader()
                   .searchNearestVectors(
-                      fieldName, randomNormalizedVector(dimension), k, liveDocs, visitedLimit);
+                      fieldName,
+                      randomNormalizedVector(dimension),
+                      k,
+                      AcceptDocs.fromLiveDocs(liveDocs, ctx.reader().maxDoc()),
+                      visitedLimit);
           assertEquals(TotalHits.Relation.EQUAL_TO, results.totalHits.relation());
           assertTrue(results.totalHits.value() <= visitedLimit);
+          assertOffHeapByteSize(ctx.reader(), fieldName);
         }
       }
     }
@@ -1562,11 +1589,16 @@ public abstract class BaseKnnVectorsFormatTestCase extends BaseIndexFileFormatTe
           TopDocs results =
               ctx.reader()
                   .searchNearestVectors(
-                      fieldName, randomNormalizedVector(dimension), k, liveDocs, Integer.MAX_VALUE);
+                      fieldName,
+                      randomNormalizedVector(dimension),
+                      k,
+                      AcceptDocs.fromLiveDocs(liveDocs, ctx.reader().maxDoc()),
+                      Integer.MAX_VALUE);
           assertEquals(Math.min(k, size), results.scoreDocs.length);
           for (int i = 0; i < k - 1; i++) {
             assertTrue(results.scoreDocs[i].score >= results.scoreDocs[i + 1].score);
           }
+          assertOffHeapByteSize(ctx.reader(), fieldName);
         }
       }
     }
@@ -1760,6 +1792,7 @@ public abstract class BaseKnnVectorsFormatTestCase extends BaseIndexFileFormatTe
               i = iter.docID();
             }
           }
+          assertOffHeapByteSize(r, fieldName);
         }
       }
     }
@@ -1828,6 +1861,7 @@ public abstract class BaseKnnVectorsFormatTestCase extends BaseIndexFileFormatTe
                       storedFields.document(byteVectorValues.ordToDoc(ord), Set.of("id"));
                   sumOrdToDocIds += Integer.parseInt(doc.get("id"));
                 }
+                assertOffHeapByteSize(ctx.reader(), "knn_vector");
               }
             }
           }
@@ -1848,6 +1882,7 @@ public abstract class BaseKnnVectorsFormatTestCase extends BaseIndexFileFormatTe
                   Document doc = storedFields.document(vectorValues.ordToDoc(ord), Set.of("id"));
                   sumOrdToDocIds += Integer.parseInt(doc.get("id"));
                 }
+                assertOffHeapByteSize(ctx.reader(), "knn_vector");
               }
             }
           }
@@ -1914,4 +1949,92 @@ public abstract class BaseKnnVectorsFormatTestCase extends BaseIndexFileFormatTe
 
     IOUtils.close(reader, w2, dir1, dir2);
   }
+
+  protected void assertOffHeapByteSize(LeafReader r, String fieldName) throws IOException {
+    var fieldInfo = r.getFieldInfos().fieldInfo(fieldName);
+
+    if (r instanceof CodecReader codecReader) {
+      KnnVectorsReader knnVectorsReader = codecReader.getVectorReader();
+      if (knnVectorsReader instanceof PerFieldKnnVectorsFormat.FieldsReader fieldsReader) {
+        knnVectorsReader = fieldsReader.getFieldReader(fieldName);
+      }
+      var offHeap = knnVectorsReader.getOffHeapByteSize(fieldInfo);
+      long totalByteSize = offHeap.values().stream().mapToLong(Long::longValue).sum();
+      if (knnVectorsReader instanceof SimpleTextKnnVectorsReader) {
+        assertEquals(0L, offHeap.size()); // all vectors are in memory
+        assertEquals(0L, totalByteSize);
+      } else {
+        if (getNumVectors(knnVectorsReader, fieldInfo) == 0) {
+          assertEquals(0L, totalByteSize);
+        } else {
+          assertTrue(totalByteSize > 0);
+          assertTrue(offHeap.get("vec") > 0L);
+
+          if (hasHNSW(knnVectorsReader, fieldInfo)) {
+            assertTrue(offHeap.get("vex") > 0L);
+            var quant = offHeap.getOrDefault("veq", offHeap.get("veb"));
+            assertTrue(quant == null || quant > 0L);
+          } else {
+            assertTrue(offHeap.get("vex") == null);
+          }
+
+          if (hasQuantized(knnVectorsReader, fieldInfo)) {
+            assertTrue(offHeap.getOrDefault("veq", offHeap.get("veb")) > 0L);
+          }
+        }
+      }
+    } else {
+      throw new AssertionError("unexpected:" + r.getClass());
+    }
+  }
+
+  static int getNumVectors(KnnVectorsReader reader, FieldInfo fieldInfo) throws IOException {
+    return switch (fieldInfo.getVectorEncoding()) {
+      case BYTE -> reader.getByteVectorValues(fieldInfo.getName()).size();
+      case FLOAT32 -> reader.getFloatVectorValues(fieldInfo.getName()).size();
+    };
+  }
+
+  static boolean hasQuantized(KnnVectorsReader knnVectorsReader, FieldInfo fieldInfo)
+      throws IOException {
+    if (fieldInfo.getVectorEncoding() == VectorEncoding.BYTE) {
+      return false; // byte vectors are never auto-quantized
+    }
+    if (knnVectorsReader
+        instanceof AssertingKnnVectorsFormat.AssertingKnnVectorsReader assertingReader) {
+      knnVectorsReader = assertingReader.delegate;
+    }
+
+    if (knnVectorsReader instanceof QuantizedVectorsReader quantReader) {
+      return quantReader.getQuantizedVectorValues(fieldInfo.name) != null;
+    }
+
+    String name = knnVectorsReader.getClass().getSimpleName().toLowerCase(Locale.ROOT);
+    return name.contains("quantized");
+  }
+
+  static boolean hasHNSW(KnnVectorsReader knnVectorsReader, FieldInfo fieldInfo)
+      throws IOException {
+    if (knnVectorsReader
+        instanceof AssertingKnnVectorsFormat.AssertingKnnVectorsReader assertingReader) {
+      knnVectorsReader = assertingReader.delegate;
+    }
+    if (knnVectorsReader instanceof HnswGraphProvider graphProvider) {
+      return graphProvider.getGraph(fieldInfo.name) != null;
+    }
+    String name = knnVectorsReader.getClass().getSimpleName().toLowerCase(Locale.ROOT);
+    return name.contains("hnsw");
+  }
+
+  public void testMergeOffHeapByteSizeMaps() {
+    Map<String, Long> map1 = Map.of("a", 0L, "b", 1L, "c", 100L);
+    Map<String, Long> map2 = Map.of("b", 2L, "c", 5L, "d", 101L, "e", 6L);
+    var r = KnnVectorsReader.mergeOffHeapByteSizeMaps(map1, map2);
+    assertEquals(r.size(), 5);
+    assertEquals(0L, (long) r.get("a"));
+    assertEquals(3L, (long) r.get("b"));
+    assertEquals(105L, (long) r.get("c"));
+    assertEquals(101L, (long) r.get("d"));
+    assertEquals(6L, (long) r.get("e"));
+  }
 }
