@@ -66,6 +66,7 @@ import org.apache.lucene.index.VectorEncoding;
 import org.apache.lucene.index.VectorSimilarityFunction;
 import org.apache.lucene.internal.tests.IndexPackageAccess;
 import org.apache.lucene.internal.tests.TestSecrets;
+import org.apache.lucene.search.DocAndFloatFeatureBuffer;
 import org.apache.lucene.search.DocIdSetIterator;
 import org.apache.lucene.store.Directory;
 import org.apache.lucene.store.FlushInfo;
@@ -114,6 +115,9 @@ public class RandomPostingsTester {
     // Check DocIdSetIterator#intoBitSet
     INTO_BIT_SET,
 
+    // Check PostingsEnum#nextDocsAndFreqs
+    NEXT_DOCS_AND_FREQS,
+
     // Sometimes check payloads
     PAYLOADS,
 
@@ -763,7 +767,7 @@ public class RandomPostingsTester {
             segmentInfo,
             newFieldInfos,
             null,
-            new IOContext(new FlushInfo(maxDoc, bytes)));
+            IOContext.flush(new FlushInfo(maxDoc, bytes)));
 
     Fields seedFields = new SeedFields(fields, newFieldInfos, maxAllowed, allowPayloads);
 
@@ -1410,6 +1414,57 @@ public class RandomPostingsTester {
         set2.clear();
       }
     }
+
+    if (options.contains(Option.NEXT_DOCS_AND_FREQS)) {
+      int flags = PostingsEnum.FREQS;
+      if (doCheckPositions) {
+        flags |= PostingsEnum.POSITIONS;
+        if (doCheckOffsets) {
+          flags |= PostingsEnum.OFFSETS;
+        }
+        if (doCheckPayloads) {
+          flags |= PostingsEnum.PAYLOADS;
+        }
+      }
+
+      for (boolean impacts : new boolean[] {false, true}) {
+        PostingsEnum pe1;
+        if (impacts) {
+          pe1 = termsEnum.impacts(flags);
+        } else {
+          pe1 = termsEnum.postings(null, flags);
+          if (random.nextBoolean()) {
+            // test reuse
+            pe1.advance(maxDoc / 2);
+            pe1 = termsEnum.postings(pe1, flags);
+          }
+        }
+        PostingsEnum pe2 = termsEnum.postings(null, flags);
+
+        pe1.nextDoc();
+        pe2.nextDoc();
+        DocAndFloatFeatureBuffer buffer = new DocAndFloatFeatureBuffer();
+        while (true) {
+          int curDoc = pe1.docID();
+          int upTo =
+              TestUtil.nextInt(random, curDoc, (int) Math.min(Integer.MAX_VALUE, curDoc + 512L));
+          pe1.nextPostings(upTo, buffer);
+          assertEquals(buffer.size == 0, curDoc >= upTo);
+
+          for (int i = 0; i < buffer.size; ++i) {
+            assertTrue(buffer.docs[i] < upTo);
+            assertEquals(pe2.docID(), buffer.docs[i]);
+            assertEquals(0f, pe2.freq(), buffer.features[i]);
+            pe2.nextDoc();
+          }
+
+          assertEquals(pe1.docID(), pe2.docID());
+          if (pe1.docID() == DocIdSetIterator.NO_MORE_DOCS) {
+            break;
+          }
+        }
+      }
+    }
   }
 
   private static class TestThread extends Thread {
